
TODO: TODO_67_33_03_53: add FS_36_17_84_44 `check_env` test support

Target: to be able to test it with `LocalServer` (and `LocalClient`).

This may require special `EnvMockBuilder` and other classes.

Also, consider splitting `check_env` plugin config into separate file.
